@@ -1,16 +1,13 @@
 package PYX::SGML::Raw;
 
-# Pragmas.
 use strict;
 use warnings;
 
-# Modules.
 use Class::Utils qw(set_params);
 use PYX::Parser;
 use PYX::Utils qw(encode entity_encode);
 
-# Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -64,6 +61,12 @@ sub parse_handler {
 	return;
 }
 
+sub finalize {
+	my $self = shift;
+	_end_of_start_tag($self->{'pyx_parser'});
+	return;
+}
+
 # Process start of element.
 sub _start_element {
 	my ($pyx_parser_obj, $elem) = @_;
@@ -144,10 +147,12 @@ PYX::SGML::Raw - Processing PYX data or file and write as SGML.
 =head1 SYNOPSIS
 
  use PYX::SGML::Raw;
+
  my $obj = PYX::SGML::Raw->new(%parameters);
  $obj->parse($pyx, $out);
  $obj->parse_file($input_file, $out);
  $obj->parse_handle($input_file_handler, $out);
+ $obj->finalize;
 
 =head1 SUBROUTINES
 
@@ -187,6 +192,11 @@ PYX::SGML::Raw - Processing PYX data or file and write as SGML.
  If $out not present, use 'output_handler'.
  Returns undef.
 
+=item C<finalize()>
+
+ Finalize opened tags, if exists.
+ Returns undef.
+
 =back
 
 =head1 ERRORS
@@ -197,11 +207,9 @@ PYX::SGML::Raw - Processing PYX data or file and write as SGML.
 
 =head1 EXAMPLE
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use PYX::SGML::Raw;
 
  # Input.
@@ -237,17 +245,24 @@ Install the PYX modules.
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/michal-josef-spacek/PYX-SGML-Raw>
+
 =head1 AUTHOR
 
-Michal Špaček L<skim@cpan.org>.
+Michal Josef Špaček L<skim@cpan.org>.
+
+L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2011-2015 Michal Špaček
- BSD 2-Clause License
+© 2011-2016 Michal Josef Špaček
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
